===========================
|cyclotron-logo| Cyclotron
===========================

.. |cyclotron-logo| image:: docs/asset/cyclotron_logo.png

.. image:: https://travis-ci.org/MainRo/cyclotron-py.svg?branch=master
    :target: https://travis-ci.org/MainRo/cyclotron-py

.. image:: https://badge.fury.io/py/cyclotron.svg
    :target: https://badge.fury.io/py/cyclotron

.. image:: https://readthedocs.org/projects/cyclotron-py/badge/?version=latest
    :target: https://cyclotron-py.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

Cyclotron is a functional and reactive framework for Python and
`RxPY <https://github.com/ReactiveX/RxPY/>`_.


Packages
=========

Cyclotron is composed of several python packages:

===========================================================  ====================
Package                                                      Version
===========================================================  ====================
`cyclotron <https://github.com/mainro/cyclotron-py>`_           |pypi-cyclotron|
`cyclotron-std <https://github.com/mainro/cyclotron-std>`_   |pypi-cyclotron-std|
`cyclotron-aio <https://github.com/mainro/cyclotron-aio>`_   |pypi-cyclotron-aio|
===========================================================  ====================

.. |pypi-cyclotron| image:: https://badge.fury.io/py/cyclotron.svg
    :target: https://badge.fury.io/py/cyclotron

.. |pypi-cyclotron-aio| image:: https://badge.fury.io/py/cyclotron-aio.svg
    :target: https://badge.fury.io/py/cyclotron-aio

.. |pypi-cyclotron-std| image:: https://badge.fury.io/py/cyclotron-std.svg
    :target: https://badge.fury.io/py/cyclotron-std
